==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appconfiguration/kotlin/inputs/PrivateEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appconfiguration.kotlin.inputs

import com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Private endpoint which a connection belongs to.
 * @property id The resource Id for private endpoint
 */
public data class PrivateEndpointArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs> {
    override fun toJava(): com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs =
        com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointArgs].
 */
@PulumiTagMarker
public class PrivateEndpointArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The resource Id for private endpoint
     */
    @JvmName("qwvrsrmhridwgoqp")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The resource Id for private endpoint
     */
    @JvmName("oiqtukhaqmwbecwi")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): PrivateEndpointArgs = PrivateEndpointArgs(
        id = id,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appconfiguration/kotlin/inputs/PrivateEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appconfiguration.kotlin.inputs

import com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Private endpoint which a connection belongs to.
 * @property id The resource Id for private endpoint
 */
public data class PrivateEndpointArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs> {
    override fun toJava(): com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs =
        com.pulumi.azurenative.appconfiguration.inputs.PrivateEndpointArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointArgs].
 */
@PulumiTagMarker
public class PrivateEndpointArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The resource Id for private endpoint
     */
    @JvmName("veoaghypbtawsdsv")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The resource Id for private endpoint
     */
    @JvmName("owacyttlfgtwmwag")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): PrivateEndpointArgs = PrivateEndpointArgs(
        id = id,
    )
}
